==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fintindex.h <==
// class soot.coffi.Instruction_intindex

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class d13384827121be19 soot_coffi_Instruction__5fintindex

// header file dependencies
// @dep_header soot_coffi_Instruction

#include "soot/coffi/Instruction.h"

#ifndef _JC_soot_coffi_Instruction__5fintindex_H_
#define _JC_soot_coffi_Instruction__5fintindex_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fintindex$sub_refs	_jc_soot_coffi_Instruction__5fintindex$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fintindex$sub_nonrefs	_jc_soot_coffi_Instruction__5fintindex$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fintindex$refs	_jc_soot_coffi_Instruction__5fintindex$refs;
typedef struct _jc_soot_coffi_Instruction__5fintindex$nonrefs	_jc_soot_coffi_Instruction__5fintindex$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fintindex$object	_jc_soot_coffi_Instruction__5fintindex$object;

typedef const struct _jc_soot_coffi_Instruction__5fintindex$vmethods	_jc_soot_coffi_Instruction__5fintindex$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fintindex$vtable	_jc_soot_coffi_Instruction__5fintindex$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fintindex$vtype	_jc_soot_coffi_Instruction__5fintindex$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fintindex$method$_init$3f3083d4dc5dd7b4(_jc_env *, struct _jc_soot_coffi_Instruction__5fintindex$object *, jbyte);

// Virtual methods
extern jint _jc_soot_coffi_Instruction__5fintindex$method$compile$7850d747d603381b(_jc_env *, struct _jc_soot_coffi_Instruction__5fintindex$object *, struct _jc_byte_array *, jint);
extern void _jc_soot_coffi_Instruction__5fintindex$method$markCPRefs$b0e03bf500f63087(_jc_env *, struct _jc_soot_coffi_Instruction__5fintindex$object *, struct _jc_boolean_array *);
extern jint _jc_soot_coffi_Instruction__5fintindex$method$nextOffset$f8d97a51150e6758(_jc_env *, struct _jc_soot_coffi_Instruction__5fintindex$object *, jint);
extern jint _jc_soot_coffi_Instruction__5fintindex$method$parse$107dd9a35b0eb485(_jc_env *, struct _jc_soot_coffi_Instruction__5fintindex$object *, struct _jc_byte_array *, jint);
extern void _jc_soot_coffi_Instruction__5fintindex$method$redirectCPRefs$777e17d486bcc287(_jc_env *, struct _jc_soot_coffi_Instruction__5fintindex$object *, struct _jc_short_array *);
extern struct _jc_java_lang_String$object *_jc_soot_coffi_Instruction__5fintindex$method$toString$9f9bf0b6fdab502b(_jc_env *, struct _jc_soot_coffi_Instruction__5fintindex$object *, struct _jc_object_array *);

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_Instruction__5fintindex$method_info$compile$7850d747d603381b;
extern _jc_method _jc_soot_coffi_Instruction__5fintindex$method_info$markCPRefs$b0e03bf500f63087;
extern _jc_method _jc_soot_coffi_Instruction__5fintindex$method_info$nextOffset$f8d97a51150e6758;
extern _jc_method _jc_soot_coffi_Instruction__5fintindex$method_info$parse$107dd9a35b0eb485;
extern _jc_method _jc_soot_coffi_Instruction__5fintindex$method_info$redirectCPRefs$777e17d486bcc287;
extern _jc_method _jc_soot_coffi_Instruction__5fintindex$method_info$toString$9f9bf0b6fdab502b;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fintindex$vmethods {
	jint	(*compile$7850d747d603381b)(_jc_env *, struct _jc_soot_coffi_Instruction__5fintindex$object *, struct _jc_byte_array *, jint);
	void	(*markCPRefs$b0e03bf500f63087)(_jc_env *, struct _jc_soot_coffi_Instruction__5fintindex$object *, struct _jc_boolean_array *);
	jint	(*nextOffset$f8d97a51150e6758)(_jc_env *, struct _jc_soot_coffi_Instruction__5fintindex$object *, jint);
	jint	(*parse$107dd9a35b0eb485)(_jc_env *, struct _jc_soot_coffi_Instruction__5fintindex$object *, struct _jc_byte_array *, jint);
	void	(*redirectCPRefs$777e17d486bcc287)(_jc_env *, struct _jc_soot_coffi_Instruction__5fintindex$object *, struct _jc_short_array *);
	struct _jc_java_lang_String$object	*(*toString$9f9bf0b6fdab502b)(_jc_env *, struct _jc_soot_coffi_Instruction__5fintindex$object *, struct _jc_object_array *);
};

// Vtable
struct _jc_soot_coffi_Instruction__5fintindex$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fintindex$vmethods	soot_coffi_Instruction__5fintindex;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fintindex$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fintindex$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fintindex$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fintindex$refs {
    _jc_soot_coffi_Instruction__5fintindex$sub_refs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fintindex$sub_nonrefs {
	jint	arg__5fi;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fintindex$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fintindex$sub_nonrefs	soot_coffi_Instruction__5fintindex;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fintindex$object {
	_jc_soot_coffi_Instruction__5fintindex$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fintindex$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fintindex$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fintindex$vtype _jc_soot_coffi_Instruction__5fintindex$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fintindex, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fintindex$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fintindex_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fintindex.h <==
// class soot.coffi.Instruction_intindex

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class d13384827121be19 soot_coffi_Instruction__5fintindex

// header file dependencies
// @dep_header soot_coffi_Instruction

#include "soot/coffi/Instruction.h"

#ifndef _JC_soot_coffi_Instruction__5fintindex_H_
#define _JC_soot_coffi_Instruction__5fintindex_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fintindex$sub_refs	_jc_soot_coffi_Instruction__5fintindex$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fintindex$sub_nonrefs	_jc_soot_coffi_Instruction__5fintindex$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fintindex$refs	_jc_soot_coffi_Instruction__5fintindex$refs;
typedef struct _jc_soot_coffi_Instruction__5fintindex$nonrefs	_jc_soot_coffi_Instruction__5fintindex$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fintindex$object	_jc_soot_coffi_Instruction__5fintindex$object;

typedef const struct _jc_soot_coffi_Instruction__5fintindex$vmethods	_jc_soot_coffi_Instruction__5fintindex$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fintindex$vtable	_jc_soot_coffi_Instruction__5fintindex$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fintindex$vtype	_jc_soot_coffi_Instruction__5fintindex$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fintindex$method$_init$3f3083d4dc5dd7b4(_jc_env *, struct _jc_soot_coffi_Instruction__5fintindex$object *, jbyte) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_coffi_Instruction__5fintindex$method$compile$7850d747d603381b(_jc_env *, struct _jc_soot_coffi_Instruction__5fintindex$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
extern void _jc_soot_coffi_Instruction__5fintindex$method$markCPRefs$b0e03bf500f63087(_jc_env *, struct _jc_soot_coffi_Instruction__5fintindex$object *, struct _jc_boolean_array *) _JC_JCNI_ATTR;
extern jint _jc_soot_coffi_Instruction__5fintindex$method$nextOffset$f8d97a51150e6758(_jc_env *, struct _jc_soot_coffi_Instruction__5fintindex$object *, jint) _JC_JCNI_ATTR;
extern jint _jc_soot_coffi_Instruction__5fintindex$method$parse$107dd9a35b0eb485(_jc_env *, struct _jc_soot_coffi_Instruction__5fintindex$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
extern void _jc_soot_coffi_Instruction__5fintindex$method$redirectCPRefs$777e17d486bcc287(_jc_env *, struct _jc_soot_coffi_Instruction__5fintindex$object *, struct _jc_short_array *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_coffi_Instruction__5fintindex$method$toString$9f9bf0b6fdab502b(_jc_env *, struct _jc_soot_coffi_Instruction__5fintindex$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_Instruction__5fintindex$method_info$compile$7850d747d603381b;
extern _jc_method _jc_soot_coffi_Instruction__5fintindex$method_info$markCPRefs$b0e03bf500f63087;
extern _jc_method _jc_soot_coffi_Instruction__5fintindex$method_info$nextOffset$f8d97a51150e6758;
extern _jc_method _jc_soot_coffi_Instruction__5fintindex$method_info$parse$107dd9a35b0eb485;
extern _jc_method _jc_soot_coffi_Instruction__5fintindex$method_info$redirectCPRefs$777e17d486bcc287;
extern _jc_method _jc_soot_coffi_Instruction__5fintindex$method_info$toString$9f9bf0b6fdab502b;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fintindex$vmethods {
	jint	(*compile$7850d747d603381b)(_jc_env *, struct _jc_soot_coffi_Instruction__5fintindex$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
	void	(*markCPRefs$b0e03bf500f63087)(_jc_env *, struct _jc_soot_coffi_Instruction__5fintindex$object *, struct _jc_boolean_array *) _JC_JCNI_ATTR;
	jint	(*nextOffset$f8d97a51150e6758)(_jc_env *, struct _jc_soot_coffi_Instruction__5fintindex$object *, jint) _JC_JCNI_ATTR;
	jint	(*parse$107dd9a35b0eb485)(_jc_env *, struct _jc_soot_coffi_Instruction__5fintindex$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
	void	(*redirectCPRefs$777e17d486bcc287)(_jc_env *, struct _jc_soot_coffi_Instruction__5fintindex$object *, struct _jc_short_array *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$9f9bf0b6fdab502b)(_jc_env *, struct _jc_soot_coffi_Instruction__5fintindex$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_coffi_Instruction__5fintindex$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fintindex$vmethods	soot_coffi_Instruction__5fintindex;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fintindex$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fintindex$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fintindex$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fintindex$refs {
    _jc_soot_coffi_Instruction__5fintindex$sub_refs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fintindex$sub_nonrefs {
	jint	arg__5fi;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fintindex$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fintindex$sub_nonrefs	soot_coffi_Instruction__5fintindex;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fintindex$object {
	_jc_soot_coffi_Instruction__5fintindex$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fintindex$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fintindex$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fintindex$vtype _jc_soot_coffi_Instruction__5fintindex$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fintindex, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fintindex$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fintindex_H_ */
